<?php

use EventPortal\Domain\Event\Models\Event;

return [
    'event' => [
        // class of your domain object
        'class' => Event::class,

        // name of the graph (default is "default")
        'graph' => 'event',

        // property of your object holding the actual state (default is "state")
        'property_path' => 'status',

        // list of all possible states
        'states' => [
            [
                'name' => 'unpublished',
                'metadata' => ['title' => 'Unpublished'],
            ],
            [
                'name' => 'registration_open',
                'metadata' => ['title' => 'Registration Open'],
            ],
            [
                'name' => 'closed',
                'metadata' => ['title' => 'Closed'],
            ],
            [
                'name' => 'post_event',
                'metadata' => ['title' => 'Post Event'],
            ],
            [
                'name' => 'archived',
                'metadata' => ['title' => 'Archived'],
            ],
        ],

        // list of all possible transitions
        'transitions' => [
            'unpublish' => [
                'from' => ['registration_open', 'close', 'archive'],
                'to' => 'unpublished',
                'metadata' => ['title' => 'To Unpublish'],
            ],
            'open' => [
                'from' => ['unpublished'],
                'to' => 'registration_open',
                'metadata' => ['title' => ' To Registration Open'],
            ],
            'post_event' => [
                'from' => ['registration_open'],
                'to' => 'post_event',
                'metadata' => ['title' => 'To Post Event'],
            ],
            'close' => [
                'from' => ['post_event'],
                'to' => 'closed',
                'metadata' => ['title' => 'To Closed'],
            ],
            'archive' => [
                'from' => ['closed'],
                'to' => 'archived',
                'metadata' => ['title' => 'To Archived'],
            ],
        ],

        // list of all callbacks
        'callbacks' => [
            // will be called when testing a transition
            'guard' => [
//                'guard_on_submitting' => [
//                    // call the callback on a specific transition
//                    'on' => 'submit_changes',
//                    // will call the method of this class
//                    'do' => ['MyClass', 'handle'],
//                    // arguments for the callback
//                    'args' => ['object'],
//                ],
//                'guard_on_approving' => [
//                    // call the callback on a specific transition
//                    'on' => 'approve',
//                    // will check the ability on the gate or the class policy
//                    'can' => 'approve',
//                ],
            ],

            // will be called before applying a transition
            'before' => [],

            // will be called after applying a transition
            'after' => [
                'history' => [
                    'do' => 'StateHistoryManager@storeHistory',
                ],
            ],
        ],
    ],
];
