<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Scope;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Delegate\Handlers\CreateDelegate;
use EventPortal\Domain\Delegate\Handlers\UpdateDelegate;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\User\Handlers\UpdateUser;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;

Form::make('delegate.create')
    ->addSaveHandler(new CreateModel)
    ->addSaveHandler(new CreateDelegate)
    ->model(new User)
    ->addFields(function () {
        return [
            Section::make()->fields([
                Text::make('First name')->rules(['required']),
                Text::make('Last name')->rules(['required']),
                Text::make('Email')->rules(['required', 'email', 'unique:users,email']),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.delegate.index'),
            Button::make('Add Delegate')
                ->method(InertiaMethod::POST())
                ->route('admin.delegate.store'),
        ];
    });

Form::make('delegate.show')
    ->addFields(function () {
        return [
            Section::make()->fields([
                Display::make('First name')->scopeTo('user'),
                Display::make('Last name')->scopeTo('user'),
            ]),
        ];
    })
    ->addActions(function (Delegate $delegate) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.delegate.index'),
            Button::make('Edit Delegate')
                ->method(InertiaMethod::VISIT())
                ->route('admin.delegate.edit', ['delegate' => $delegate]),
        ];
    });


Form::make('delegate.edit')
    ->addSaveHandler(new UpdateUser)
    ->addSaveHandler(new UpdateDelegate)
    ->addFields(function () {
        return [
            Section::make()->fields([
                Scope::make('user')->fields([
                    Text::make('First name')->rules(['required']),
                    Text::make('Last name')->rules(['required']),
                ]),
                Text::make('Email')
                    ->scopeTo('user')
                    ->rules(['required', 'email']),
            ]),
        ];
    })
    ->addActions(function (Delegate $delegate) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.delegate.index'),
            Button::make('Update Delegate')
                ->method(InertiaMethod::POST())
                ->route('admin.delegate.update', ['delegate' => $delegate]),
        ];
    });
