<?php

namespace EventPortal\Domain\Delegate\Listeners;

use EventPortal\Domain\Delegate\Events\DelegateCreated;
use EventPortal\Domain\Delegate\Events\DelegateEdited;
use EventPortal\Domain\Delegate\Notifications\NotifyOfCreation;
use EventPortal\Domain\Delegate\Notifications\NotifyOfEdit;
use Illuminate\Events\Dispatcher;

class DelegateEventSubscriber
{
    public function handleDelegateCreated(DelegateCreated $event): void
    {
        $delegate = $event->delegate;
        $delegate->notify(new NotifyOfCreation($delegate));
    }

    public function handleDelegateEdited(DelegateEdited $event): void
    {
        $delegate = $event->delegate;
        $delegate->notify(new NotifyOfEdit($delegate));
    }

    public function subscribe(Dispatcher $events): void
    {
        $events->listen(
            DelegateCreated::class,
            self::class.'@handleDelegateCreated',
        );

        $events->listen(
            DelegateEdited::class,
            self::class.'@handleDelegateEdited',
        );
    }
}
