<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Concerns\HasStatus;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Iben\Statable\Statable;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Event extends Model implements AuditableInterface
{
    use HasTable,
        AddToFillable,
        AddToCasts,
        Auditable,
        Statable,
        HasStatus;

    public const KEY = 'event';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'url',
        'status',
    ];

    protected function getGraph(): string
    {
        return 'event';
    }

    public function delegates(): BelongsToMany
    {
        return $this
            ->belongsToMany(Delegate::class)
            ->using(EventDelegate::class)
            ->withPivot(['status'])
            ->withTimestamps();
    }
}
