<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Permission\Models\Group;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Permission\Resources\Group as GroupResource;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Support\Arr;
use Inertia\Inertia;
use Inertia\Response;

class PermissionController extends Controller
{
    public function index(): Response
    {
        $roles = Role::all();

        $columns = Arr::collapse($roles->map(function (Role $role) {
            return [$role->slug => $role->name];
        }));

        $data = Group::with('permissions')
            ->get(['id', 'name', 'slug'])
            ->map(function (Group $group) use ($roles): array {
                return (new GroupResource($group, $roles))->toArray();
            });

        $breadcrumbs = Breadcrumb::make()
            ->add('Admin', route('admin.dashboard.index'))
            ->add('Permissions', route('admin.permission.index'))
            ->get();

        return Inertia::render('Permission/Index', [
            'data' => compact('columns', 'data'),
            'breadcrumb' => $breadcrumbs,
        ]);
    }
}
