<?php

namespace EventPortal\Tests\Feature\Admin\EventDelegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Delegate\Notifications\NotifyOfCreation;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Support\Facades\Notification;
use Spatie\Snapshots\MatchesSnapshots;

class EventDelegateCreateTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test */
    public function create_a_delegate_and_assign_to_event(): void
    {
        $this->markTestSkipped('DEPENDS: MEPS-251. Need "magic" accessor to validate presence of updates');

        $event = factory(Event::class)->create();
        $this->assertCount(0, $event->delegates);

        $this->post(route('admin.event.delegate.store', $event), [
            'first_name' => 'Test',
            'last_name' => 'Delegate',
            'profession' => 'Tester',
        ]);

        $this->assertCount(1, Delegate::all());
        $this->assertCount(1, $event->fresh()->delegates);

        $delegate = Delegate::first();

        $this->assertEquals('Test', $delegate->first_name);
        $this->assertEquals('Delegate', $delegate->last_name);
        $this->assertEquals('Tester', $delegate->profession);

        $this->assertDatabaseHas('event_user', [
            'user_id' => $delegate->id,
            'event_id' => $event->id,
            'status' => Delegate::STATUS_ADDED,
        ]);
    }

    /** @test */
    public function delegate_gets_notification_when_created(): void
    {
        Notification::fake();

        $event = factory(Event::class)->create();
        $this->assertCount(0, $event->delegates);

        $this->post(route('admin.event.delegate.store', $event), [
            'first_name' => 'Test',
            'last_name' => 'Delegate',
            'profession' => 'Tester',
        ]);

        $this->assertCount(1, Delegate::all());
        $this->assertCount(1, $event->fresh()->delegates);

        $delegate = Delegate::first();
        Notification::assertSentTo($delegate, NotifyOfCreation::class);
    }
}
