<?php

namespace EventPortal\Tests\Unit\Form;

use Closure;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Fields\EventFields;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class FormTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function makes_instance()
    {
        $form = Form::make('test.create');

        $this->assertInstanceOf(\EventPortal\Domain\Form\Form::class, $form);
    }

    /** @test **/
    public function makes_mutiple_instances()
    {
        $formA = Form::make('test.create');
        $formB = Form::make('test.edit');

        $this->assertNotSame($formA, $formB);
        $this->assertEquals('test.create', $formA->name);
        $this->assertEquals('test.edit', $formB->name);
    }

    /** @test **/
    public function can_add_array_of_fields()
    {
        $form = Form::make('test.create')
            ->addFields(function () {
                return [
                    Section::make('Key Details')->fields([
                        Text::make('Name'),
                    ]),
                ];
            });

        $this->assertIsArray($form->blocks);
        $this->assertEquals(1, count($form->blocks));
    }

    /** @test **/
    public function can_call_add_fields_multiple_times()
    {
        $form = Form::make('test.create')
            ->addFields(function () {
                return [
                    Section::make('Key Details')->fields([
                        Text::make('Name'),
                    ]),
                ];
            })
            ->addFields(function () {
                return [
                    Text::make('Email'),
                ];
            });

        $this->assertIsArray($form->blocks);
        $this->assertEquals(2, count($form->blocks));
    }

    /** @test **/
    public function field_without_section_creates_invisible_section()
    {
        $form = Form::make('test.create')
            ->model(new Event)
            ->addFields(function () {
                return [
                    Text::make('Email'),
                ];
            })
            ->render();

        $this->assertInstanceOf(Section::class, head($form['content']));
    }

    /** @test **/
    public function can_add_fields_with_a_string()
    {
        $form = Form::make('test.create')->addFields(EventFields::class);

        $this->assertEquals(EventFields::class, head($form->blocks));
    }

    /** @test **/
    public function can_add_fields_with_a_callable()
    {
        $form = Form::make('test.create')->addFields(function () {
            return [
                Text::make('name'),
            ];
        });

        $this->assertTrue(head($form->blocks) instanceof Closure);
    }
}
